/***********************************************************************
    This file is in the public domain.

    Description:
    
    A simple invocation of the Camwire library for IEEE 1394 cameras.

    Compile and link with something like:

    $ gcc hello.c -o hello -lcamwire -ldc1394 -lm

    $Id: hello.c,v 20.2 2013/08/14 01:47:07 johanns Exp $

***********************************************************************/

#include <stdio.h>

#include "camwire/camwirebus.h"  /* Camwire_handle, camwire_bus_...() */
#include "camwire/camwire.h"     /* Camwire_handle, Camwire_id, camwire_...() */


int main()
{
    int num_cameras;
    Camwire_handle *handle_array;
    Camwire_handle c_handle;
    int camwire_return;
    Camwire_id camid;
    
    /* Initialize the bus: */
    handle_array = camwire_bus_create(&num_cameras);
    if (num_cameras <= 0 || !handle_array)
    {
	fprintf(stderr, "Could not initialize the camera bus.  "
		"There may not be a camera connected.\n");
	camwire_bus_destroy();
	return 1;
    }
    if (num_cameras == 1)
	printf("Found one camera.\n");
    else
	printf("Found %d cameras.  Working with the first one.\n", num_cameras);

    /* Initialize the camera: */
    c_handle = handle_array[0];
    camwire_return = camwire_create(c_handle);
    if (camwire_return != CAMWIRE_SUCCESS)
    {
	fprintf(stderr, "Could not initialize the camera.\n");
	camwire_destroy(c_handle);
	camwire_bus_destroy();
	return 1;
    }

    /* Print some info: */
    camwire_get_identifier(c_handle, &camid);
    printf("Vendor name:       %s\n", camid.vendor);
    printf("Model name:        %s\n", camid.model);
    printf("Vendor & chip ID:  %s\n", camid.chip);

    /* Clean up: */
    camwire_destroy(c_handle);
    camwire_bus_destroy();
    
    return 0;
} /* main() */
